.. meta::
   :description: Gaitalytics User Guide.
   :keywords: gaitalytics, gait-analysis, mocap, c3d, gait-metrics, biomechanics, time-series, data-analysis, data, gait, guide, tutorial

User Guide
==========

Getting started with Gaitalytics needs some understanding of processes and flows which this framework follows.
Following overview will help you get started with necessary steps to process your data.

.. image:: ../_static/images/Gailtalytics_schema.png
    :alt: Gaitalytics Logo
    :align: center

As shown in the above image, Gaitalytics is a framework which is designed to process motion data and extract useful metrics from it.
It takes care of following steps in the processing pipeline:

    1. Data Loading
    2. Event Detection
    3. Segmentation
    4. Feature Extraction
    5. Time Normalisation
    6. Data Export

Each of these steps are explained in detail in the following pages.

.. toctree::
   :maxdepth: 2
   :hidden:

   data_loading
   event_detection
   segmentation
   features
   normalisation
   export

..





